v0.5.2
======

Fixed bug in CLI.

v0.5.1
======

Cleaned up README and other references to ``abodepy``.

v0.5.0
======

Added ``abode`` command, superseding ``abodepy``.

v0.4.0
======

Moved modules to ``jaraco.abode``.

v0.3.0
======

Package now uses relative imports throughout.

Prefer pytest for assertions.

General cleanup.

v0.2.0
======

Refreshed packaging. Enabled automated releases.

Require Python 3.7 or later.

v0.1.0
======

Initial release based on `abodepy 1.2.1 <https://pypi.org/project/abodepy>`_.
